@@ -2,13 +2,10 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import configuration
-from . import recurrence
-from . import service
-from . import subscription
-from . import invoice
-from . import party
-from . import ir
+
+from . import (
+    configuration, invoice, ir, party, product, recurrence, service,
+    subscription)
 
 
 def register():
@@ -17,6 +14,8 @@ def register():
         configuration.ConfigurationSequence,
         recurrence.RecurrenceRuleSet,
         recurrence.RecurrenceRule,
+        recurrence.TestRecurrenceRuleSetView,
+        recurrence.TestRecurrenceRuleSetViewResult,
         service.Service,
         subscription.Subscription,
         subscription.Line,
@@ -24,11 +23,13 @@ def register():
         subscription.CreateLineConsumptionStart,
         subscription.CreateSubscriptionInvoiceStart,
         invoice.InvoiceLine,
+        product.Product,
         ir.Cron,
         module='sale_subscription', type_='model')
     Pool.register(
         subscription.CreateLineConsumption,
         subscription.CreateSubscriptionInvoice,
+        recurrence.TestRecurrenceRuleSet,
         party.Replace,
         party.Erase,
         module='sale_subscription', type_='wizard')
